@@ -22,7 +22,14 @@
 #include <bonobo/bonobo-control.h>
 #include <bonobo/bonobo-control-frame.h>
 #include <gdk/gdkprivate.h>
+#if defined (GDK_WINDOWING_X11)
 #include <gdk/gdkx.h>
+#elif defined (GDK_WINDOWING_WIN32)
+#include <gdk/gdkwin32.h>
+#elif defined (GDK_WINDOWING_QUARTZ)
+#else
+#error Port to this GDK backend
+#endif
 #include <gdk/gdktypes.h>
 #include <gtk/gtkhbox.h>
 #include <bonobo/bonobo-socket.h>
@@ -64,7 +71,7 @@ control_connection_died_cb (gpointer connection,
 
 	g_return_if_fail (frame != NULL);
 
-	dprintf ("The remote control end died unexpectedly");
+	dbgprintf ("The remote control end died unexpectedly");
 
 	CORBA_exception_init (&ev);
 
@@ -120,8 +127,13 @@ impl_Bonobo_ControlFrame_getToplevelId (PortableServer_Servant  servant,
 
 		id = Bonobo_ControlFrame_getToplevelId (frame, ev);
 	} else
+#if defined (GDK_WINDOWING_X11)
 		id = bonobo_control_window_id_from_x11 (
 			GDK_WINDOW_XWINDOW (toplev->window));
+#elif defined (GDK_WINDOWING_WIN32)
+		id = bonobo_control_window_id_from_x11 (
+			(guint32) GDK_WINDOW_HWND (toplev->window));
+#endif
 
 	return id;
 }
@@ -274,7 +286,7 @@ bonobo_control_frame_get_remote_window (BonoboControlFrame *frame,
 
 	g_return_if_fail (BONOBO_IS_CONTROL_FRAME (frame));
 
-	dprintf ("bonobo_control_frame_get_remote_window "
+	dbgprintf ("bonobo_control_frame_get_remote_window "
 		 "%p %p %d %p\n", frame->priv, frame->priv->socket,
 		 GTK_WIDGET_REALIZED (frame->priv->socket),
 		 frame->priv->control);
@@ -293,7 +305,7 @@ bonobo_control_frame_get_remote_window (BonoboControlFrame *frame,
 	/* Introduce ourselves to the Control. */
 	id = bonobo_control_frame_get_remote_window_id (frame, ev);
 	if (BONOBO_EX (ev)) {
-		dprintf ("getWindowId exception\n");
+		dbgprintf ("getWindowId exception\n");
 		bonobo_object_check_env (BONOBO_OBJECT (frame),
 					 frame->priv->control, ev);
 
@@ -302,7 +314,7 @@ bonobo_control_frame_get_remote_window (BonoboControlFrame *frame,
 		BonoboPlug *plug = NULL;
 
 		xid = bonobo_control_x11_from_window_id (id);
-		dprintf ("setFrame id '%s' (=%d)\n", id, xid);
+		dbgprintf ("setFrame id '%s' (=%u)\n", id, xid);
 		CORBA_free (id);
 
 		{
@@ -382,7 +394,7 @@ bonobo_control_frame_dispose (GObject *object)
 {
 	BonoboControlFrame *frame = BONOBO_CONTROL_FRAME (object);
 
-	dprintf ("bonobo_control_frame_dispose %p\n", object);
+	dbgprintf ("bonobo_control_frame_dispose %p\n", object);
 
 	if (frame->priv->socket)
 		bonobo_control_frame_set_socket (frame, NULL);
@@ -403,7 +415,7 @@ bonobo_control_frame_finalize (GObject *object)
 {
 	BonoboControlFrame *frame = BONOBO_CONTROL_FRAME (object);
 
-	dprintf ("bonobo_control_frame_finalize %p\n", object);
+	dbgprintf ("bonobo_control_frame_finalize %p\n", object);
 
 	g_free (frame->priv);
 	
