@@ -18,7 +18,7 @@
 #include <bonobo/bonobo-ui-toolbar-button-item.h>
 #include <bonobo/bonobo-window.h>
 
-#include <bonobo/bonobo-i18n.h>
+#include <glib/gi18n.h>
 #include <bonobo/bonobo-ui-main.h>
 #include <bonobo/bonobo-ui-preferences.h>
 
@@ -124,6 +124,7 @@ cb_do_hide_toolbar (GtkWindow *window, BonoboWindow *win)
 		bonobo_ui_component_set_prop (global_component, path, "hidden", "0", NULL);
 	else
 		bonobo_ui_component_set_prop (global_component, path, "hidden", "1", NULL);
+	g_free (val);
 }
 
 static void
